<?php

/**
 * DNS Blacklist
 *
 * Plugin sets $_SESSION['dnsblacklisted'] = [list host ... e.g. 19.240.20.217.bl.spamcop.net] if client IP is blacklisted
 *        or   $_SESSION['dnsblacklisted'] = 'pass' if IP check passed
 *        and  $_SESSION['clientip'] in any case.
 *
 * @version 1.4 - 21.08.2011
 * @author Roland 'rosali' Liebl
 * @website http://myroundcube.googlecode.com
 * @licence GNU GPL
 *
 **/

/**
 * Usage: http://mail4us.net/myroundcube/
 *
 **/

class dnsbl extends rcube_plugin
{

  private $ip; //='203.176.130.6'; // Bad IP Address;

  function init() {
    $this->_load_config();
    $rcmail = rcmail::get_instance();
    $this->add_hook('startup', array($this, 'dnsbl_do'));
    // block at least sending messages ::: $rcmail_config['dnsblacklists_logout'] = FALSE;
    $this->add_hook('message_outgoing_headers', array($this, 'dnsbl_block_sending'));

  }

  function _load_config() {
    $rcmail = rcmail::get_instance();
    $config = "plugins/dnsbl/config/config.inc.php";
    if(file_exists($config))
      include $config;
    else if(file_exists($config . ".dist"))
      include $config . ".dist";
    if(is_array($rcmail_config)){
      if(is_array($rcmail_config['settingsnav']) && is_array($rcmail->config->get('settingsnav'))){
        $nav = array_merge($rcmail->config->get('settingsnav'), $rcmail_config['settingsnav']);
        $rcmail_config['settingsnav'] = $nav;
      }
      $arr = array_merge($rcmail->config->all(),$rcmail_config);
      $rcmail->config->merge($arr);
    }
  }

  function dnsbl_do($args) {
    if($this->dnsbl_check()){
      $rcmail = rcmail::get_instance();
      if($rcmail->config->get('dnsblacklists_logout')){
        $args['task'] = 'logout';
        $this->add_texts('localization/');
        $rcmail->output->show_message('dnsbl.dnsblacklisted','error');
        if(method_exists($rcmail->output,'add_script')){
          $rcmail->output->add_script('$("input[type=\'submit\']").attr("disabled","disabled")','foot');
          $rcmail->output->add_script('$(document).ready(function(){$("#taskbar").html("")})','foot');
        }
      }
    }
    return $args;
  }

  function dnsbl_block_sending($args){
    if($_SESSION['dnsblacklisted'] != 'pass'){
      $this->add_texts('localization/');
      $rcmail = rcmail::get_instance();
      $rcmail->output->show_message('dnsbl.dnsblacklisted','error');
      $rcmail->output->send('iframe');
    }
    return $args;
  }

  function dnsbl_check(){
    if($this->ip == ""){
      $this->ip = $this->getVisitorIP();
    }
    if($this->ip == ""){
      return false;
    }
    if(empty($_SESSION['dnsblacklisted'])){
      // set flag for a whole browser session !!!
      $_SESSION['clientip'] = $this->ip;
      if($res = $this->dnsbl_blacklisted($this->ip)){
        $_SESSION['dnsblacklisted'] = $res;
        if($this->ip)
          $this->log(sprintf("--> Positive DNSBL result detected for IP %s", $this->ip));
        return true;
      }
      else{
        $_SESSION['dnsblacklisted'] = 'pass';
      }
    }

    if($_SESSION['dnsblacklisted'] != 'pass')
      return true;

    return false;
  }

  function getVisitorIP() {
    global $HTTP_SERVER_VARS;

    //Regular expression pattern for a valid IP address
    $ip_regexp = "/^([0-9]{1,3})\.([0-9]{1,3})\.([0-9]{1,3})\.([0-9]{1,3})/";

    //Retrieve IP address from which the user is viewing the current page
    if (isset ($HTTP_SERVER_VARS["HTTP_X_FORWARDED_FOR"]) && !empty ($HTTP_SERVER_VARS["HTTP_X_FORWARDED_FOR"])) {
      $visitorIP = (!empty ($HTTP_SERVER_VARS["HTTP_X_FORWARDED_FOR"])) ? $HTTP_SERVER_VARS["HTTP_X_FORWARDED_FOR"] : ((!empty ($HTTP_ENV_VARS['HTTP_X_FORWARDED_FOR'])) ? $HTTP_ENV_VARS['HTTP_X_FORWARDED_FOR'] : @ getenv ('HTTP_X_FORWARDED_FOR'));
    }
    else {
      $visitorIP = (!empty ($HTTP_SERVER_VARS['REMOTE_ADDR'])) ? $HTTP_SERVER_VARS['REMOTE_ADDR'] : ((!empty ($HTTP_ENV_VARS['REMOTE_ADDR'])) ? $HTTP_ENV_VARS['REMOTE_ADDR'] : @ getenv ('REMOTE_ADDR'));
    }

    if (strpos($visitorIP, ',')!==false) {
	    $visitorIP = trim(end(explode(',',$visitorIP)));
    }

    if(!$visitorIP)
      $visitorIP = "detection failed";
    return $visitorIP;
  }

  function dnsbl_blacklisted($ip) {
    $rcmail = rcmail::get_instance();
    $dnsbl_lists = $rcmail->config->get('dnsblacklists', array());
    $reverse_ip = implode(".", array_reverse(explode(".", $ip)));
    foreach ($dnsbl_lists as $dnsbl_list => $val){
      if($val != 0){
        $prefix = '';
        if($val != 1){
          $prefix = $val . ".";
        }
        // trailing dot needed to prevent search domain additions.
        $lookup = $prefix . $reverse_ip . "." . $dnsbl_list . ".";
        $recs = @dns_get_record($lookup, DNS_A);
        if(is_array($recs)){
          break;
        }
      }
    }
    if(is_array($recs) && count($recs) > 0){
      $this->log("DNSBL: " . $reverse_ip . "." . $dnsbl_list);
      return $reverse_ip . "." . $dnsbl_list;
    }
    else
      return false;
  }

  function log($log){
    $rcmail = rcmail::get_instance();
    if($rcmail->config->get('dnsblacklists_log')){
      write_log('dnsbl',$log);
    }
  }
}

?>
