<?php

/**
 * SAUserPrefs configuration file
 */

// spamassassin database settings
//$config['sauserprefs_db_dsnw'] = 'mysql://username:password@localhost/database';
$ini = parse_ini_file( '/usr/local/interworx/lib/roundcube/iworx.ini', true );
$config['sauserprefs_db_dsnw'] = $ini['vpopmail.spam']['dsn'];

// PEAR database DSN for read only operations (if empty write database will be used)
// useful for database replication
$config['sauserprefs_db_dsnr'] = '';

// use persistent db-connections
// beware this will not "always" work as expected
// see: http://www.php.net/manual/en/features.persistent-connections.php
$config['sauserprefs_db_persistent'] = false;

// table that holds user prefs
$config['sauserprefs_sql_table_name'] = 'userpref';

// name of the username field in the user prefs table
$config['sauserprefs_sql_username_field'] = 'username';

// name of the preference field in the user prefs table, holds the name of the preference
$config['sauserprefs_sql_preference_field'] = 'preference';

// name of the value field in the user prefs table, holds the value of the preference
$config['sauserprefs_sql_value_field'] = 'value';

// username of the current user in the database, normaly %u (username from the session info)
//      %u is replaced with the username (from the session info)
//      %l is replaced with the local part of the username (if the username is an email address)
//      %d is replaced with the domain part of the username (if the username is an email address or default mail domain if not)
//      %i is replaced with the email address from the user's default identity
//$config['sauserprefs_userid'] = '%u';

// username of the global or default settings user in the database, normaly $GLOBAL or @GLOBAL
$config['sauserprefs_global_userid'] = '\$GLOBAL';

// enable address whitelist synchronisation with address book(s)
// possible values:
//   false - synchronisation disabled
//   true - synchronise with default address book
//   array - an array of address book ids to synchronise with e.g. array('0', 'global'); '0' = the default address book
$config['sauserprefs_abook_sync'] = false;

// set to false to disable address book import
// possible values:
//   false - address import disabled
//   true - import addresses from default address book
//   array - an array of address book ids to import e.g. array('0', 'global'); '0' = the default address book
$config['sauserprefs_abook_import'] = false;

// don't allow these settings to be overriden by the user
// eg. $config['sauserprefs_dont_override'] = array('required_score','rewrite_header Subject');
// to disable entire sections enter the secion name surrounded by braces. Sections are: general,tests,bayes,headers,report,addresses
// eg. $config['sauserprefs_dont_override'] = array('{tests}');
$config['sauserprefs_dont_override'] = array();

// activate SAUserPrefs for selected mail hosts only. If this is not set all mail hosts are allowed.
// example: $config['sauserprefs_allowed_hosts'] = array('mail1.domain.tld', 'mail2.domain.tld');
$config['sauserprefs_allowed_hosts'] = null;

// load specific config for different mail hosts
// example: $config['sauserprefs_host_config'] = array(
//    'mail1.domain.tld' => 'mail1_config.inc.php',
//    'mail2.domain.tld' => 'mail2_config.inc.php',
// );
$config['sauserprefs_host_config'] = null;

// default settings
// these are overridden by $GLOBAL and user settings from the database
$config['sauserprefs_default_prefs'] = array( "required_score" => "5",
                                                     "rewrite_header Subject" => "*****SPAM*****",
                                                     "ok_languages" => "all",
                                                     "ok_locales" => "all",
                                                     "fold_headers" => "1",
                                                     "add_header all Level" => "_STARS(*)_",
                                                     "use_razor1" => "0",
                                                     "use_razor2" => "1",
                                                     "use_pyzor" => "1",
                                                     "use_dcc" => "1",
                                                     "use_bayes" => "1",
                                                     "skip_rbl_checks" => "0",
                                                     "report_safe" => "1",
                                                     "bayes_auto_learn" => "1",
                                                     "bayes_auto_learn_threshold_nonspam" => "0.1",
                                                     "bayes_auto_learn_threshold_spam" => "12.0",
                                                     "use_bayes_rules" => "1"
                                                     );

// score options
// define the ranges for the various score select boxes
// '[field name]' => array('min' => [min], 'max' => [max], 'increment' => [increment], 'extra' => array())
// note: the 'extra' key is optional and should contain further arrays with min, max and increment keys
$config['sauserprefs_score_options'] = array(
                                    '*' => array('min' => 1, 'max' => 10, 'increment' => 1),
                                    '_bayesnonspam' => array('min' => -1, 'max' => 1, 'increment' => 0.1),
                                    '_bayesspam' => array('min' => 1, 'max' => 20, 'increment' => 1),
                                    '_score_user_blacklist' => array('min' => 0, 'max' => 100, 'increment' => 10, 'extra' => array(array('min' => 1, 'max' => 10, 'increment' => 1))),
                                    '_score_user_whitelist' => array('min' => -100, 'max' => -1, 'increment' => 10, 'extra' => array(array('min' => -10, 'max' => -1, 'increment' => 1)))
                                );

// delete user bayesian data stored in database
// the query can contain the following macros that will be expanded as follows:
//      %u is replaced with the username from the sauserprefs_userid setting above
// use an array to run multiple queries
// set to null to disable this option
$config['sauserprefs_bayes_delete_query'] = array(
                                              'DELETE FROM bayes_seen WHERE id IN (SELECT id FROM bayes_vars WHERE username = %u);',
                                              'DELETE FROM bayes_token WHERE id IN (SELECT id FROM bayes_vars WHERE username = %u);',
                                              'DELETE FROM bayes_vars WHERE username = %u;'
                                              );

// allowed languages
// set to array of language codes to limit the language list available for the ok_languages option
// eg array('en', 'es', 'ru', 'zh');
// see the README for a full list of supported languages
// set to null for all possible languages
$config['sauserprefs_languages'] = array(
                                                                        "af" => "Afrikaans",
                                                                        "sq" => "Albanian",
                                                                        "am" => "Amharic",
                                                                        "ar" => "Arabic",
                                                                        "hy" => "Armenian",
                                                                        "eu" => "Basque",
                                                                        "bs" => "Bosnian",
                                                                        "bg" => "Bulgarian",
                                                                        "be" => "Byelorussian",
                                                                        "ca" => "Catalan",
                                                                        "zh" => "Chinese",
                                                                        "hr" => "Croatian",
                                                                        "cs" => "Czech",
                                                                        "da" => "Danish",
                                                                        "nl" => "Dutch",
                                                                        "en" => "English",
                                                                        "eo" => "Esperanto",
                                                                        "et" => "Estonian",
                                                                        "fi" => "Finnish",
                                                                        "fr" => "French",
                                                                        "fy" => "Frisian",
                                                                        "ka" => "Georgian",
                                                                        "de" => "German",
                                                                        "el" => "Greek",
                                                                        "he" => "Hebrew",
                                                                        "hi" => "Hindi",
                                                                        "hu" => "Hungarian",
                                                                        "is" => "Icelandic",
                                                                        "id" => "Indonesian",
                                                                        "ga" => "Irish Gaelic",
                                                                        "it" => "Italian",
                                                                        "ja" => "Japanese",
                                                                        "ko" => "Korean",
                                                                        "la" => "Latin",
                                                                        "lv" => "Latvian",
                                                                        "lt" => "Lithuanian",
                                                                        "ms" => "Malay",
                                                                        "mr" => "Marathi",
                                                                        "ne" => "Nepali",
                                                                        "no" => "Norwegian",
                                                                        "fa" => "Persian",
                                                                        "pl" => "Polish",
                                                                        "pt" => "Portuguese",
                                                                        "qu" => "Quechua",
                                                                        "rm" => "Rhaeto-Romance",
                                                                        "ro" => "Romanian",
                                                                        "ru" => "Russian",
                                                                        "sa" => "Sanskrit",
                                                                        "sco" => "Scots",
                                                                        "gd" => "Scottish Gaelic",
                                                                        "sr" => "Serbian",
                                                                        "sk" => "Slovak",
                                                                        "sl" => "Slovenian",
                                                                        "es" => "Spanish",
                                                                        "sw" => "Swahili",
                                                                        "sv" => "Swedish",
                                                                        "tl" => "Tagalog",
                                                                        "ta" => "Tamil",
                                                                        "th" => "Thai",
                                                                        "tr" => "Turkish",
                                                                        "uk" => "Ukrainian",
                                                                        "vi" => "Vietnamese",
                                                                        "cy" => "Welsh",
                                                                        "yi" => "Yiddish"
                                                                );
